@@ -323,7 +323,7 @@ class ClientApplication(Frame):
         Frame.__init__(self, master)
         self._init_gui()
         self._game = None
-        self._prepare_debug_game()
+        #self._prepare_debug_game() # uncomment it to make testing easier
 
     def _prepare_debug_game(self):
         # load game and add player
@@ -345,7 +345,7 @@ class ClientApplication(Frame):
 
         set_program(6, 'gather.py', 'py')
         set_program(2, 'build_tank.py', 'py')
-        set_program(3, 'gather.py', 'py')
+        set_program(3, 'move_randomly.py', 'py')
         set_program(4, 'move_randomly.py', 'py')
         set_program(5, 'move.cpp', 'cpp')
 
@@ -420,14 +420,9 @@ class ClientApplication(Frame):
         if not self._ask_if_delete_current_game_if_exists():
             return
 
-        stream = tkFileDialog.askopenfile(
-            title='Choose map file',
-            filetypes=ClientApplication.MAP_FILETYPES,
-            parent=self)
-        if stream is None:
-            return
-
         try:
+            filename = datafile_path('maps/default.map')
+            stream = open(filename, 'r')
             game_map = pickle.load(stream)
         except pickle.UnpicklingError as ex:
             self._warning('Create new game',
