@@ -35,10 +35,6 @@ DEFAULT_PYTHON_LANGUAGE = Language(
     name='python',
     source_extension='.py',
     binary_extension='.py',
-
-    # There is 'cp' command under Linux and 'copy' under Windows. The
-    # following trick works under both systems.
-    compilation_command='copy src.py bin.py', #'cp src.py bin.py && copy src.py bin.py',
-
+    compilation_command='cp src.py bin.py',
     running_command='python bin.py',
 )
